"""causal_toolkit_tc - Causal Inference Toolkit"""

__version__ = "0.1.0"
# Import key functions for easy access
from .rct import calculate_ate_ci, calculate_ate_pvalue
from .propensity import ipw, doubly_robust
from .meta_learners import (
s_learner_discrete,
t_learner_discrete,
x_learner_discrete,
double_ml_cate
)
__all__ = [
"calculate_ate_ci",
"calculate_ate_pvalue",
"ipw",
"doubly_robust",
"s_learner_discrete",
"t_learner_discrete",
"x_learner_discrete",
"double_ml_cate",
]